Release notes
#############

All notable changes to this project will be documented in there.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

.. include:: ../../CHANGES.rst
